<?php
/**
 * WP Less is More Theme Customizer functionality
 *
 * @package WordPress
 * @subpackage WP Less is More
 * @since WP Less is More 1.1.1
 */

## firt let's define some custom sanitize functions 

function wp_less_is_more_sanitize_text( $text ){
	
	$allowed_html = array(
		'a' => array(
			'href' => array(),
		),
		'br' => array(),
		'del' => array (
			'datetime' => array(),
		),	
		'em' => array(),
		'i' => array(),
		'q' => array(
			'cite' => array(),
		),
		's' => array(),
		'strike' => array(),
		'strong' => array(),
	);

	$text = wp_kses( $text, $allowed_html );

	return  $text;	
}

function wp_less_is_more_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

function wp_less_is_more_sanitize_numbers( $number ) {
	// number check.
	return absint( $number );
}

## Next, define some default helper functions

/** Default footer text **/

function wp_less_is_more_default_footer_text(){
	$default_footer_text = sprintf( esc_html__( 'Copyright &copy; by %s', 'wp-less-is-more' ), get_bloginfo( 'name' ) );	
	return $default_footer_text;
}

/** Default excerpt length **/

function wp_less_is_more_default_excerpt_length(){
	return 55;
}


## Then register theme customizer

function wp_less_is_more_theme_customize ( $wp_customize ) {
		
	/*
	 * Failsafe is safe
	 */
	if ( ! isset( $wp_customize ) ) {
		return;
	}
	

	/******************************************
	 *                                        *
	 *      Option One - Custom Footer        *
	 *                                        *
	 ******************************************
	 */
	
	$wp_customize->add_section( 
		'wp_less_is_more_custom_footer_section',
		array(
			'title'      => __('Custom footer','wp-less-is-more'),
			'description'	=> sprintf( __( 'Use this option to be able to control the footer text. It is enabled by default and looks like this: <strong><i>%s</i></strong>',  'wp-less-is-more' ),
			wp_less_is_more_default_footer_text() ),

	) );
	
	
	/******************************************
	 *                                        *
	 *      Option Two - Excerpt Lenght       *
	 *                                        *
	 ******************************************
	 */
	 
	$wp_customize->add_section( 
		'wp_less_is_more_excerpt_length_section',
		array(
			'title'      => __('Excerpt lenght','wp-less-is-more'),
			'description'	=> sprintf( __( 'Use this option to control the excerpt lenght on the home page.
The default length is 55 words. This setting works only when a post themplate use <code>%s</code> template tag and the excerpt is created automatically (excerpt meta box on the post editor screen is empty) but no longer than the <code>%s</code> tag (if it\'s used).
See: <a href="%s" target="_blank">Excerpt</a> or <a href="%s" target="_blank">Customizing_the_Read_More</a> in codex.', 'wp-less-is-more'),
			esc_html__( 'the_excerpt' ),
			esc_html__( '&lt;!--more--&gt;' ),
			esc_url('https://codex.wordpress.org/Excerpt'),
			esc_url('https://codex.wordpress.org/Customizing_the_Read_More'))

	) );	
	
	
	/******************************************
	 *                                        *
	 *               Settings                 *
	 *                                        *
	 ******************************************
	 */
	
	/* 
	 * Footer Text 
	 *
	 * Return Values:
	 * (boolean) 
	 * True on success, false on failure.
	 *
	 **/
	
	$wp_customize->add_setting(
		// $id
		'display_footer_text',
		// $args
		array(
			'default'			=> true,
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'wp_less_is_more_sanitize_checkbox'
		)
	);
	
	/*
	 * Custom Footer Text 
	 *
	 * Return Values:
	 * (string) 
	 * Value set for the option
	 *
	 **/
	
	$wp_customize->add_setting(
		'custom_footer_text',
		array(
			'capability'     => 'edit_theme_options',
			'type'           => 'theme_mod',
			'sanitize_callback' => 'wp_less_is_more_sanitize_text'
		)
	);

	/*
	 * Excerpt lenght
	 *
	 * Return Values:
	 * (int) 
	 * A non-negative integer.
	 *
	 **/

	$wp_customize->add_setting(
		'excerpt_length',
		array(
			'default' => wp_less_is_more_default_excerpt_length(),
			'capability'     => 'edit_theme_options',
			'type'           => 'theme_mod',
			'sanitize_callback' => 'wp_less_is_more_sanitize_numbers',
		)
	);
	
	
	/******************************************
	 *                                        *
	 *               Controls                 *
	 *                                        *
	 ******************************************
	 */

	$wp_customize->add_control(
		// $id
		'display_footer_text_control',
		// $args
		array(
			'label'			=> __( 'Display footer text', 'wp-less-is-more' ),	
			'settings'		=> 'display_footer_text',
			'section'		=> 'wp_less_is_more_custom_footer_section',
			'type'			=> 'checkbox'
	)
	);
	
	$wp_customize->add_control(
		'custom_footer_control', 
		array(
			'label'    => __( 'Text in footer:', 'wp-less-is-more' ),
			'description' => sprintf( __( 'Use this field to override the default footer text. If nothing specified, default text will be used instead. You may use these HTML tags and attributes: <code>%s</code>.', 'wp-less-is-more' ), esc_html( '<a href="" title=""> <b> <del datetime=""> <em> <i> <q cite=""> <s> <strike> <strong> ' )),
			'section'  => 'wp_less_is_more_custom_footer_section',
			'settings' => 'custom_footer_text',
			'type'     => 'text'
		)
	);
	
	$wp_customize->add_control(
    'excerpt_length_control',
		array(
			'label' => __( 'Use the slider or enter a number:', 'wp-less-is-more' ),
			'settings' => 'excerpt_length',	
			'section' => 'wp_less_is_more_excerpt_length_section',			
			'type' => 'range',
			'input_attrs' => array(
				'min' => 1,
				'max' => 200,
				'step' => 1,
				'style' => 'color: red',
			),
		)
	);

	$wp_customize->add_control(
    '_excerpt_length_control',
		array(
			'description' => __( 'Available slider range: 1 to 200', 'wp-less-is-more' ),
			'settings' => 'excerpt_length',	
			'section' => 'wp_less_is_more_excerpt_length_section',			
			'type' => 'number',
		)
	);

}
add_action( 'customize_register', 'wp_less_is_more_theme_customize', 11 );