<?php

/*
 * This is Bootstrap to WordPress theme called: WP Less is More.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * WP Less is More supports.
 *
 * @uses load_theme_textdomain() for translation/localization support.
 * @uses add_editor_style() to add Visual Editor stylesheets.
 * @uses add_theme_support() to add support for automatic feed links, post
 * formats, and post thumbnails.
 * @uses register_nav_menu() to add support for a navigation menu.
 * @uses set_post_thumbnail_size() to set a custom post thumbnail size.
 *
 * @since WP Less is More 1.0
 */
 

function wp_less_is_more_theme_setup() {

	/*
	 * Set the content width based on the theme's design and stylesheet.
	 */
		global $content_width;
		
		if ( ! isset( $content_width ) ) {
		$content_width = 692;
	}
		
	/*
	 * Makes WP Less is More available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on WP Less is More, use a find and
	 * replace to change 'wp-less-is-more' to the name of your theme in all
	 * template files.
	 */
	load_theme_textdomain( 'wp-less-is-more', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	// This theme uses wp_nav_menu() in two locations.
	
		register_nav_menus( array (
		'top'	 => __( 'Top Menu', 				'wp-less-is-more'),
		'bottom' => __( 'Bottom Menu', 	'wp-less-is-more')
		));

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	
	/*
	 * Enable support for custom logo.
	 *
	 */

	 $defaults = array(
		'header-text'           => false,
		'random-default'		=> false,
		'width'					=> 700,
		'height'				=> 100,
		'flex-height'			=> false,
		'flex-width'			=> false,
		'uploads'				=> true,

	);
	add_theme_support( 'custom-header', $defaults );
	add_theme_support( 'custom-background', $args = array());
	add_editor_style();
	
}
add_action( 'after_setup_theme', 'wp_less_is_more_theme_setup' );

	/*
	 * Customizer additions.
	 *
	 * @since WP Less is More 1.1.1
	 */

 require trailingslashit( get_template_directory() ) . 'customizer/customizer.php';
	
	/*
	 * ** Define Dropdowns Bootstrap Menu **
	 *
	 * ** If you want to have dropdowns, bootstrtap menu, you have to:
	 * 	1) Register Custom Navigation Walker
	 * 	2) Replaces "current-menu-item" with "active"
	 * 	3) Deletes all CSS classes and id's, except for those listed in the @array
	 * 	4) Deletes empty classes and removes the sub menu class
	 *
	 * @since WP Less is More 1.0
	 **/
	
require trailingslashit( get_template_directory() ) . 'bootstrap/wp_less_is_more_bootstrap_navwalker.php';
	
	/*
	 * 	Deletes all CSS classes and id's, except for those listed in the array below
	 **/
	
function wp_less_is_more_custom_wp_nav_menu( $var ) {
		return is_array( $var ) ? array_intersect( $var, array(
				//List of allowed menu classes
				'current-menu-item',
				'current_page_item',
				'current_page_parent',
				'current_page_ancestor',
				'first',
				'last',
				'vertical',
				'horizontal'
				)
		) : '';
}
 
	/* 
	 * Replaces "current-menu-item" with "active" - for bootstrap menu8
	 * @since WP Less is More 1.0
	 **/ 

function wp_less_is_more_current_to_active( $text ){
		$replace = array(
			//List of menu item classes that should be changed to "active"
			'current-menu-item' 	=> 'active',
			'current_page_item' 	=> '1',
			'current_page_parent' 	=> '2',
			'current_page_ancestor' => '3',
		);
		$text = str_replace(array_keys( $replace ), $replace, $text );
			return $text;
		}

	/*
	 * Deletes empty classes and removes the sub menu class
	 *
	 * @since WP Less is More 1.0
	 **/

function wp_less_is_more_strip_empty_classes( $menu ) {
    $menu = preg_replace( '/ class=""| class="sub-menu"/',' class="dropdown-menu"', $menu );
    return $menu;
}

add_filter ( 'nav_menu_css_class',  'wp_less_is_more_custom_wp_nav_menu' );
add_filter ( 'nav_menu_item_id'	 ,	'wp_less_is_more_custom_wp_nav_menu' );
add_filter ( 'page_css_class'	 , 	'wp_less_is_more_custom_wp_nav_menu' );
add_filter ( 'wp_nav_menu'		 ,	'wp_less_is_more_current_to_active'	 );
add_filter ( 'wp_nav_menu'		 ,	'wp_less_is_more_strip_empty_classes');


	/*
	 * This function add img-responsive class within the_content included post_thumbnails.
	 * If you want to have responsive images outside the_content you have to add this class manually.
	 *
	 *  Responsive images: 
	 * 	1) add img-responsive class 
	 * 	2) remove dimensions 
	 *
	 * @since WP Less is More 1.0
	 **/
	
function wp_less_is_more_bootstrap_responsive_images( $html ){
  $classes = 'img-responsive'; // separated by spaces, e.g. 'img image-link'
  
  // check if there are already classes assigned to the anchor
  if ( preg_match( '/<img.*? class="/', $html ) ) {

    $html = preg_replace( '/(<img.*? class=".*?)(".*?\/>)/', '$1 ' . $classes . ' $2', $html );
	
  } else {
	  
    $html = preg_replace( '/(<img.*?)(\/>)/', '$1 class="' . $classes . '" $2', $html );
	
  }
  
  // remove dimensions from images,, does not need it!
  $html = preg_replace( '/(width|height)=\"\d*\"\s/', "", $html );
  
  return $html;
}

	/*
	 * This function removes dimensions from post_thumbnails.
	 *
	 * @since WP Less is More 1.1.2
	 **/

function wp_less_is_more_remove_width_and_height( $html, $post_id, $post_thumbnail_id, $size, $attr )
{
    $html = preg_replace( '/ (width|height)="[^"]+"/', '', $html );
    return $html;
}
add_filter( 'the_content',	'wp_less_is_more_bootstrap_responsive_images', 10 );
add_filter( 'post_thumbnail_html', 'wp_less_is_more_remove_width_and_height', 10, 5 );


	/*
	 * 	This function is replacement for:
	 *	@the_posts_pagination();
	 *	and is used on home.php template
	 *
	 * 	It shows nice and clear posts pagination tailored to Bootstrap Theme
	 *
	 * @since WP Less is More 1.0
	 **/
	
function wp_less_is_more_numeric_posts_nav() {
	global $wp_query;
	
	if( is_singular() )
		return;

	/** Stop execution if there's only 1 page */
	if( $wp_query->max_num_pages <= 1 )
		return;

	$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
	$max   = intval( $wp_query->max_num_pages );

	/**	Add current page to the array */
	if ( $paged >= 1 )
		$links[] = $paged;

	/**	Add the pages around the current page to the array */
	if ( $paged >= 3 ) {
		$links[] = $paged - 2;
		
		// Uncomment this variable if you want to have more pages in array
		//$links[] = $paged - 3;
	}

	if ( ( $paged + 2 ) <= $max ) {
		
		// Uncomment this variable if you want to have more pages in array
		//$links[] = $paged + 3;
		$links[] = $paged + 2;
	}

	echo '<nav class="text-center"><ul class="pagination">' . "\n";

	/**	Previous Post Link */
	if ( get_previous_posts_link() )
		printf( '<li>%s</li>' . "\n", get_previous_posts_link() );

	/**	Link to first page, plus ellipses if necessary */
	if ( ! in_array( 1, $links ) ) {
		$class = 1 == $paged ? ' class="active"' : '';

		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );

		if ( ! in_array( 2, $links ) )
			echo '<li></li>';
	}

	/**	Link to current page, plus 2 pages in either direction if necessary */
	sort( $links );
	foreach ( ( array ) $links as $link ) {
		$class = $paged == $link ? ' class="active"' : '';
		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
	}

	/**	Link to last page, plus ellipses if necessary */
	if ( ! in_array( $max, $links ) ) {
		if ( ! in_array( $max - 1, $links ) )
			echo '<li></li>' . "\n";

		$class = $paged == $max ? ' class="active"' : '';
		printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
	}

	/**	Next Post Link */
	if ( get_next_posts_link() )
		printf( '<li>%s</li>' . "\n", get_next_posts_link() );

	echo '</ul></nav>' . "\n";

}

	/*
	 *  Custom template for comments list
	 **/

function wp_less_is_more_custom_comments_list_template( $comment, $args, $depth ) {
	global $comment_depth;
	
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag 		= 'div';
		$add_below 	= 'div-comment';
	} else {
		$tag 		= 'li';
		$add_below 	= 'comment';
	}
	
	
?>	
	<<?php echo $tag ?> style="list-style-type: none;" <?php comment_class( empty( $args['has_children'] ) ? 'alone' : 'this parent' ) ?> id="comment-<?php comment_ID(); ?>">
	
	<div class="media-left">
	<?php if ( $args['avatar_size'] != 0 ) 	echo get_avatar( $comment,  $args['avatar_size'], '', '', $arg = array( 'class' => '' ) ); ?>
	</div>
	<?php if ( $comment->comment_approved == '0' ) : ?>
		<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'wp-less-is-more' ); ?></em>
		<br />
	<?php endif; ?>

<div class="media-body">
	<h4 class="media-heading">
	<?php printf( __( '<cite class="fn">%s</cite> <span class="says">says:</span>', 'wp-less-is-more' ), get_comment_author_link() ); ?></h4>

	<?php comment_text();
	
	comment_reply_link( array_merge( $args, array(
	
		'add_below'	=> $add_below,
		'depth'		=> $depth,
		'max_depth'	=> $args['max_depth'],
		'reply_text'=> __( 'Reply', 'wp-less-is-more' ) . '&nbsp;<span class="glyphicon glyphicon-share-alt" aria-hidden="true"></span>',
		'before'	=> '<p>',
		'after'		=> '</p>'
		
		) ) ); ?>

</div>

<?php
}


	/*
	 * Custom Link Pages
	 * @author toscha
	 * @link http://wordpress.stackexchange.com/questions/14406/how-to-style-current-page-number-wp-link-pages
	 * @param  array $args
	 * @return void
	 * Modification of wp_link_pages() with an extra element to highlight the current page.
	 * Edited by: WPSolucje
	 * We added only 2 extra params: @current_before and @current_after
	 * Enjoy!
	 *
	 * @since WP Less is More 1.0
	 */
	 
function wp_less_is_more_bootstrap_link_pages( $args = array () ) {
	global $page, $numpages, $multipage, $more, $pagenow;
	
	$defaults = array(
		'before'		=> '',
		'after'			=> '',
		'before_link'	=> '',
		'after_link'	=> '',
		'current_before'=> '',
		'current_after'	=> '',
		'link_before'	=> '',
		'link_after'	=> '',
		'pagelink'		=> '%',
		'separator'		=> ' ',
		'echo'			=> 1
	);
	
	$r = wp_parse_args( $args, $defaults );
	$r = apply_filters( 'wp_link_pages_args', $r );
	extract( $r, EXTR_SKIP );

	if ( ! $multipage )
	{
		return;
	}
	$output = $before;
	for ( $i = 1; $i < ( $numpages + 1 ); $i++ )
	{
		$j = str_replace( '%', $i, $pagelink );
	
	$output .= ( 1 === $i ) ? ' ' : "{$separator}";
		if ( $i != $page || ( ! $more && 1 == $page ) )
		{
			$output .= "{$before_link}" . _wp_link_page( $i ) . "{$link_before}{$j}{$link_after}</a>{$after_link}";
		}
		else
		{
			$output .= "{$current_before}{$j}{$current_after}";
		}
			
	}
	print $output . $after;
}


	/*
	 * Registers a widget area.
	 *
	 * @link https://developer.wordpress.org/reference/functions/register_sidebar/
	 *
		*
		* 	You've got four widgets area
		* 	1) on the left bottom side of the site
		* 	2) in the left middle - bottom
		* 	3) in the right bottom side 
		*   4) on the right bottom side
		*
		* @since WP Less is More 1.0
		*
		**/
	
function wp_less_is_more_widgets_init() {
	register_sidebar( array(
		'name'			=> __( 'Left Bottom Widget Area', 'wp-less-is-more' ),
		'id'			=> 'sidebar-left',
		'description'	=> __( 'Appears on the left-bottom side of the page.', 'wp-less-is-more' ),
		'before_widget'	=> '',
		'after_widget'	=> '',
		'before_title'	=> '<h3>',
		'after_title'	=> '</h3>',
	) );
	register_sidebar( array(
		'name'			=> __( 'Middle Left  Bottom Widget Area', 'wp-less-is-more' ),
		'id'			=> 'sidebar-middle-left',
		'description'	=> __( 'Appears on the middle-bottom side of the page.', 'wp-less-is-more' ),
		'before_widget'	=> '',
		'after_widget'	=> '',
		'before_title'	=> '<h3>',
		'after_title'	=> '</h3>',
	) );
	register_sidebar( array(
		'name'			=> __( 'Middle Right Bottom Widget Area', 'wp-less-is-more' ),
		'id'			=> 'sidebar-middle-right',
		'description'	=> __( 'Appears on the right-bottom side of the page.', 'wp-less-is-more' ),
		'before_widget'	=> '',
		'after_widget'	=> '',
		'before_title'	=> '<h3>',
		'after_title'	=> '</h3>',
	) );
	register_sidebar( array(
		'name'			=> __( 'Right Bottom Widget Area', 'wp-less-is-more' ),
		'id'			=> 'sidebar-right',
		'description'	=> __( 'Appears on the right-bottom side of the page.', 'wp-less-is-more' ),
		'before_widget'	=> '',
		'after_widget'	=> '',
		'before_title'	=> '<h3>',
		'after_title'	=> '</h3>',
	) );

}
add_action( 'widgets_init', 'wp_less_is_more_widgets_init' );


	/*
	 *  Enqueue scripts and styles.
	 *
	 * @since WP Less is More 1.0
	 */

function wp_less_is_more_enqueue_js_and_css() {

	wp_enqueue_script( 'bootstrap', get_stylesheet_directory_uri() . '/bootstrap/js/bootstrap.min.js', array( 'jquery' ), null, true );
	
	wp_enqueue_style( 'bootstrap', get_stylesheet_directory_uri() . '/bootstrap/css/bootstrap.min.css', false, null, 'all' );
	 
	wp_enqueue_style( 'bootstrap-joombotron-narrow', get_stylesheet_directory_uri() . '/bootstrap/css/jumbotron-narrow.css', false, null, 'all' );
	 
	wp_enqueue_style( 'wp-less-is-more-style',	get_stylesheet_directory_uri() . '/style.css', false, null, 'all' );
		
	if ( is_single() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	/**
	*
	* HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries
	*
	**/
	
	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/bootstrap/js/html5shiv.min.js',   false, null, true );
	wp_enqueue_script( 'respond',	 get_template_directory_uri() . '/bootstrap/js/respond.min.js',	false, null, true );
	
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );
    wp_script_add_data( 'respond',   'conditional', 'lt IE 9' );

}
add_action( 'wp_enqueue_scripts', 'wp_less_is_more_enqueue_js_and_css' );

	/*
	 * ** Custom Site Title **
	 *
	 * This function changes the way you see (in header section)
	 * your site tile (or blog name), depends on different pages
	 * See line: 27 in header.php file
	 *
	 * @since WP Less is More 1.1.0.8
	 **/

function wp_less_is_more_site_title(){
	
	// if tere is tag page display: tag name
	if ( is_tag() ) {
		
		$site_title =  single_tag_title( __( 'Tag:&nbsp;', 'wp-less-is-more'), true );
	}
		// if there is category page display: category name
		elseif ( is_category() ) {
			
			$site_title =  single_tag_title( __( 'Category:&nbsp;', 'wp-less-is-more'), true ) . '&nbsp;';
		}
			// if there is attachment page display: Attachment
			elseif ( is_attachment() ) {
				
				$site_title =  __( 'Attachment', 'wp-less-is-more');
			}
				// if there is author page display: Author + author name
				elseif ( is_author()   ) {
					
					$site_title =  __( 'Author:', 'wp-less-is-more') . ' ' . get_the_author();
				}
					// if there is archive display: Archive
					elseif ( is_archive()  ) {
						
						$site_title =  __( 'Archive', 'wp-less-is-more');
					}
							
						// if there is custom page templete used display page title
						elseif( is_page_template( 'page_list-child-pages.php' ) ) {
							
							$site_title =  the_title();
						}
							// in other any cases display hyperlinked blog name
							else {
								
								$site_title =  '<a class="navbar-brand" href="' . esc_url( home_url( '/' ) ) . '">' .  get_bloginfo( 'name' ) . '</a>';
							}
	echo $site_title;	
}

	/*
	 * Enqueue script for custom customize control.
	 */
	 
function wp_less_is_more_customize_enqueue_js() {
	wp_enqueue_script( 'wp-less-is-more-custom-customize', get_template_directory_uri() . '/customizer/js/wp_less_is_more_show_if_checked.js', array( 'jquery', 'customize-controls' ), false, true );
}
add_action( 'customize_controls_enqueue_scripts', 'wp_less_is_more_customize_enqueue_js' );


	/*
	 *
	 *  ** Excerpt lenght **
	 *
	 * By default the excerpt length is set to return 55 words.
	 * This filter is used to change excerpt lenght.
	 *
	 *
	 * @since WP Less is More 1.1.1
	 **/

function wp_less_is_more_excerpt_length( $length ) {
	
	$_excerpt_length = wp_less_is_more_default_excerpt_length();
	$excerpt_length = get_theme_mod('excerpt_length', $_excerpt_length );
	
	if ( $excerpt_length == $_excerpt_length )
		return $_excerpt_length;
	else return $excerpt_length;	
}
add_filter( 'excerpt_length', 'wp_less_is_more_excerpt_length', 999 );

	/**
	 *
	 ** Cutom Footer Text
	 *
	 * @since WP Less is More 1.1.1
	 */

function wp_less_is_more_custom_footer_text(){
	/*
	 * let's get data from database once only
	 */
	$custom_footer_text = get_theme_mod('custom_footer_text');
	$display_footer_text = get_theme_mod('display_footer_text', 1);
	// if checkbox is checked
	if ( $display_footer_text == true )
		
		//if input field is empty
		if ( $custom_footer_text == '' )
			
			// print default
			echo wp_less_is_more_default_footer_text();
			
		// else print custom	
		else echo $custom_footer_text;
}


/*
 * Collapse in/out comment list
 *
 * This function handle collapse behavior to create an accordion comment list
 *
 * @param int 		$max_page 	The maximum number of comment pages.
 * @param int 		$page 		Check for current page number.
 * @param string 	$default	Determine which page is displayed by default.
 * 								There are two options: 'newest' and 'oldest'.
 *
 * 
 *	Comments are collapse if:
 *	
 *	- pagination is @off
 *  - @param $page is the first page in pagination queue
 *  - or equal to maximum number of comment pages
 *  	*) when @newest $max_page == $page
 *  	**) when @oldest $page == 1
 *
 *	Comments are collapse in if:
 *	- pagination is @on and @param $page in not the firt one in pagination queue
 *	- $param $replytocom is true
 *
 *	Then from the given data you need to decide whether comments can collapse in or not.
 *	By @default comments are collapsed.
 *
 * @since WP_Less_is_More 1.1.1
 **/	

function wp_less_is_more_collapse_comments_list(){
	// If have comments do action
	if ( have_comments() ) {
	
		$max_page = get_comment_pages_count();		
		$page = ( $max_page == 1 ) ? 1 : get_query_var('cpage');		
		$default = get_option('default_comments_page');		
		
		if ( true == get_option('page_comments') ){	 

			switch ( $default ){
			
				case 'newest':
					// 5 : 5
					$in = ( $page == $max_page ) ? '' : 'in'; 
				break; 

				case 'oldest':
					// 5:1
					$in = ( $page == 1 ) ? '' : 'in';	 
				break;	
			}
	
		} else {		
			
			$in = '';		
		}
		
		if ( isset( $_GET['replytocom'] ) ) {			
			$in = 'in';		 
		}
		
		return $in . ' ' . $page . $max_page . $default;		
	}
}

/*
 * Auxiliary function for reply to collapse in comments form
 *
 * @since WP_Less_is_More 1.1.1
 **/

function wp_less_is_more_is_reply(){

	$_in = isset( $_GET['replytocom'] ) ? 'in' : '';

	return $_in;
}

	/*
	 * Action hook to prevent empty divisions
	 * This hook wraps comments form within div tags
	 * and prevents against emptiness (or white break) if comments are closed
	 * because you can't add custom class to default WordPress form tag
	 *
	 * @since WP Less is More 1.1.1
	 **/

function wp_less_is_more_comment_form_before(){

	echo '<div class="' . esc_attr( 'panel-body' ) . '" style="' . esc_attr( 'padding-top: 0px;' ) . '">';
}

function wp_less_is_more_comment_form_after(){

	echo '</div>';
}
add_action( 'comment_form_before', 'wp_less_is_more_comment_form_before', 10 );
add_action( 'comment_form_after', 'wp_less_is_more_comment_form_after', 10 );